Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CommandHandler ¶
CommandHandler represents a function that handles a specific command
type Executor ¶
type Executor struct {
// contains filtered or unexported fields
}
Executor implements commandexec.Executor for testing
func NewExecutor ¶
func NewExecutor() *Executor
func (*Executor) AddHandler ¶
func (e *Executor) AddHandler(fullCommand string, handler CommandHandler)
AddHandler registers a handler for a specific full command string
Click to show internal directories.
Click to hide internal directories.